@@ -1,6 +1,6 @@
 """
 A simple async Python wrapper for nekos.best API.
-Copyright (C) 2021  PredaaA
+Copyright (C) 2021-present  PredaaA
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published
@@ -57,13 +57,15 @@ class Result:
     Attributes
     ----------
     url: Optional[str]
-        The image url.
+        The image / gif url.
     artist_href: Optional[str]
         The artist's page URL.
     artist_name: Optional[str]
         The artist's name.
     source_url: Optional[str]
         The original link of this image.
+    anime_name: Optional[str]
+        The englified name of the anime the gif was taken from.
     """
 
     def __init__(self, data: dict):
@@ -71,6 +73,7 @@ class Result:
         self.artist_href: Optional[str] = data.get("artist_href")
         self.artist_name: Optional[str] = data.get("artist_name")
         self.source_url: Optional[str] = data.get("source_url")
+        self.anime_name: Optional[str] = data.get("anime_name")
 
     def __repr__(self) -> str:
-        return f"<Result url={self.url} artist_href={self.artist_href} artist_name={self.artist_name} source_url={self.source_url}>"
+        return f"<Result url={self.url} artist_href={self.artist_href} artist_name={self.artist_name} source_url={self.source_url} anime_name={self.anime_name}>"
